//
// Fragment shader for billboard
//
// Author: Byungil Jeong
//

uniform sampler2D colorMap;
uniform vec3  mortarColor;
uniform bool  drawPost;
varying bool  showContents;

uniform bool  dayTime;
varying vec3  normal, ecLightPos, ecVertexPos;

uniform float offset;

void main(void)
{
	const float ambient = 0.1;
	float texOffset = fract(offset);
	vec2 texCoord = vec2(gl_TexCoord[0].x + texOffset, gl_TexCoord[0].y);
   vec4 myColor = texture2D(colorMap, texCoord);

	vec3 lightVec = ecLightPos - ecVertexPos;
	float dist = length(lightVec);
	vec3 lightDir = normalize(lightVec);
	
	vec3 fragNormal = normalize(normal);
	float intensity = 1.5*max(dot(lightDir, -fragNormal), 0.0);

	if (drawPost || !showContents)
		intensity = 0.0;

	if (intensity > 0.0) {
		float attenuation = 1.0/(1.0 + 0.001*dist*dist);
		if (!dayTime)
			myColor *= (intensity * attenuation + ambient);
	}
	else
		myColor = vec4(mortarColor*0.2, 1.0);

	gl_FragColor = myColor;
}
